#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hsini
version:              0.5.2.2
visibility:           public
id:                   hsini-0.5.2.2-JRgbxKjRjVN3izz9q4vs5w
key:                  hsini-0.5.2.2-JRgbxKjRjVN3izz9q4vs5w
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
author:               Magnus Therning <magnus@therning.org>
synopsis:             ini configuration files
description:
    Library for reading and writing configuration files in INI format (see <https://en.wikipedia.org/wiki/INI_file>).

category:             Configuration, Data
abi:                  b80e917238b12506cc39a97ff8610362
exposed:              True
exposed-modules:
    Data.Ini Data.Ini.Reader Data.Ini.Reader.Internals Data.Ini.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hsini-0.5.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hsini-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hsini-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsini
hs-libraries:         HShsini-0.5.2.2-JRgbxKjRjVN3izz9q4vs5w
depends:
    base-4.18.2.1 containers-0.6.7 mtl-2.3.1 parsec-3.1.16.1

haddock-interfaces:   /usr/share/doc/haskell-hsini/html/hsini.haddock
haddock-html:         /usr/share/doc/haskell-hsini/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

